<template>
	<div class="bbsl-common-page">
		<div class="bbsl-table-search">
			<el-form v-model="queryParam" label-width="auto">
				<el-row :gutter="10">
					<el-col :span="5">
						<el-form-item label="被考核者">
							<el-input clearable placeholder="请输入被考核者姓名" v-model="querys[1].value"
								maxlength="64"></el-input>
						</el-form-item>
					</el-col>
					<el-col :span="5">
						<el-form-item label="考核日期">
							<el-date-picker clearable style="width: 100%" value-format="yyyy-MM-dd"
								placeholder="请输入考核日期" v-model="querys[2].value"></el-date-picker>
						</el-form-item>
					</el-col>
					<el-col :span="5">
						<el-form-item label="考核标题">
							<el-input clearable placeholder="请输入考核标题" v-model="querys[3].value"
								maxlength="64"></el-input>
						</el-form-item>
					</el-col>
					<el-col :span="4">
						<el-button type="primary" icon="el-icon-search" @click="handleSearch">搜索</el-button>
						<el-button icon="el-icon-refresh" @click="handleReset">重置</el-button>
					</el-col>
				</el-row>
			</el-form>
		</div>
		<div class="bbsl-table-content" ref="contentPanel">
			<div class="bbsl-btn-content" ref="btnPanel">
				<el-button icon="el-icon-plus" type="primary" @click="handleAdd">新增</el-button>
				<el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
					<el-button slot="reference" :disabled="!multipleSelection.length" icon="el-icon-delete"
						style="margin-left: 10px">删除</el-button>
				</el-popconfirm>
			</div>
			<el-table border size="mini" v-loading="loading" ref="multipleSelection" :data="tableData"
				:style="{ width: '100%' }" :max-height="tableMaxHeight" :cell-style="{ 'text-align': 'center' }"
				:header-cell-style="{ 'text-align': 'center' }" @row-dblclick="handleDbClick"
				@selection-change="handleSelectionChange">
				<el-table-column type="selection" width="55"></el-table-column>
				<el-table-column type="index" width="55" label="序号"></el-table-column>
				<el-table-column min-width="100" prop="reference" label="被考核者" show-overflow-tooltip>
				</el-table-column>
				<el-table-column min-width="200" prop="assessTitle" label="考核标题" show-overflow-tooltip>
				</el-table-column>
				<el-table-column min-width="120" prop="assessUser" label="考核人员" show-overflow-tooltip>
				</el-table-column>
				<el-table-column min-width="100" prop="assessDate" label="考核日期" show-overflow-tooltip>
				</el-table-column>

				<el-table-column min-width="100" prop="result" label="考核得分" show-overflow-tooltip>
					<template slot-scope="scope">
						<el-tag size="medium" type="danger">{{ scope.row.result }}</el-tag>
					</template>
				</el-table-column>
			</el-table>
			<el-pagination align="right" background class="bbsl-pagination" ref="paginationPanel"
				@size-change="handleSizeChange" @current-change="handleCurrentChange"
				:current-page="queryParam.pageBean.page" :page-sizes="[20, 30, 40, 50]"
				:page-size="queryParam.pageBean.pageSize" layout="total, sizes, prev, pager, next, jumper"
				:total="total"></el-pagination>
		</div>
		<UnitCheckDialog ref="formModal"></UnitCheckDialog>
	</div>
</template>

<script>
import {
	TableMixin
} from '@/mixins/tableMixin'
import operationCheck from '@/api/device/operationCheck.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import UnitCheckDialog from '@/views/Device/operationCheck/components/UnitCheckDialog.vue'
export default {
	name: 'UnitCheck',
	components: {
		UnitCheckDialog,
	},
	mixins: [TableMixin],
	data() {
		return {
			url: {
				delete: '/device/appraiseInfo/',
			},
			assessTypeList: [], //考核方式字段
			querys: [{
				group: 'main',
				operation: 'EQUAL',
				parentGroup: '',
				property: 'dai.assess_type_',
				relation: 'AND',
				value: '1',
			},
			{
				group: 'main',
				operation: 'LIKE',
				parentGroup: '',
				property: 'dai.assess_user_',
				relation: 'AND',
				value: '',
			},
			{
				group: 'main',
				operation: 'EQUAL',
				parentGroup: '',
				property: 'dai.assess_Date_',
				relation: 'AND',
				value: '',
			},
			{
				group: 'main',
				operation: 'LIKE',
				parentGroup: '',
				property: 'dab.ASSESS_TITLE_',
				relation: 'AND',
				value: '',
			},
			],
		}
	},
	created() {
		this.assessTypeList = dictUtils.getDictItemsFromCache('jxkh-khfs')
	},
	mounted() { },
	methods: {
		// 重置
		clearQuerys() {
			this.querys[1].value = ''
			this.querys[2].value = ''
			this.querys[3].value = ''
		},
		// 获取list
		loadData(page) {
			if (page) {
				this.queryParam.pageBean.page = page
			}
			this.loading = true
			this.tableData = []
			this.queryParam.querys = []
			if (this.querys[0].value) {
				this.queryParam.querys.push(this.querys[0])
			}
			if (this.querys[1].value) {
				this.queryParam.querys.push(this.querys[1])
			}
			if (this.querys[2].value) {
				this.queryParam.querys.push(this.querys[2])
			}
			if (this.querys[3].value) {
				this.queryParam.querys.push(this.querys[3])
			}
			operationCheck.loadAppraiseInfo(this.queryParam, (res) => {
				this.total = res.total
				this.tableData = res.rows
				this.$set(this.tableData)
				this.loading = false
				console.log(this.tableData, 8888)
			})
		},
	},
}
</script>
<style lang="scss" scoped></style>
